package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@(!`0````````````,`MP`!````^",```````!```````````"B````
M`````````$``.``(`$``&@`9``8````%````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````/25````````])4`````````
M``$```````$````&````&)L````````8FP$``````!B;`0``````H`4`````
M``#(%0```````````0```````@````8````PFP```````#";`0``````,)L!
M```````@`@```````"`"````````"``````````$````!````!P"````````
M'`(````````<`@```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````8FP```````!B;`0``````&)L!``````#H!```````
M`.@$`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`,GD%YO/7^^D*NU.;'Y@63%*BB`,1````40````0````(````(1`0``7`
M!(0H`A`!@(9`@((I``0)(`2)B*`81;H$`@A1````4@```%8```!;````7```
M`&,```!D````90```&<```!H`````````&H```!K````;````&X`````````
M``````&O-.ANQ=\?ZM/O#L[>1RUK?YI\+L6;MG94/)0@_^0.N(WQ#M5DU'S9
M<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75[(D'
M<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````````
M`````````````````````````````P`+`'@=````````````````````````
M`P`3`"B;`0````````````````#3`@``$@````````````````````````!7
M`P``$@````````````````````````"C`@``$@``````````````````````
M``"J`@``$@````````````````````````!)`P``$@``````````````````
M``````!*`@``$@`````````````````````````1````(```````````````
M``````````#[`@``$@`````````````````````````3`P``$@``````````
M```````````````Z`P``(@`````````````````````````,`P``$@``````
M``````````````````#S`@``$@````````````````````````#(````$@``
M```````````````````````%`P``$0````````````````````````"7`0``
M$@`````````````````````````X`@``$@````````````````````````!7
M`@``$@````````````````````````"8````$@``````````````````````
M```@`0``$@`````````````````````````<`P``$@``````````````````
M``````"<`@``$@````````````````````````"^`0``$@``````````````
M```````````5`0``$0````````````````````````#:`@``$@``````````
M``````````````![`0``$@````````````````````````#W````$0``````
M``````````````````!)`0``$@````````````````````````!/`@``$@``
M``````````````````````!M`P``$@````````````````````````"Q`@``
M$@````````````````````````#6````$@````````````````````````#%
M`0``$@`````````````````````````A`@``$@``````````````````````
M``"R`0``$@````````````````````````#O`0``$@``````````````````
M``````"'`@``$@````````````````````````!@`@``$@``````````````
M``````````!I`@``$@`````````````````````````#`@``$@``````````
M``````````````!7`0``$@`````````````````````````M````(```````
M``````````````````"?`P``$0````````````````````````"``P``(0``
M``````````````````````"/`@``$@````````````````````````!?`P``
M$@````````````````````````#0`0``$0````````````````````````!X
M````$@````````````````````````#%`@``$@``````````````````````
M``!F`P``$@`````````````````````````>!```$@``````````````````
M``````"_`@``$@````````````````````````"G````$@``````````````
M``````````"S````$@````````````````````````!P`0``$@``````````
M``````````````#H`@``$@`````````````````````````V`0``$@``````
M```````````````````E`0``$@````````````````````````!J````$@``
M```````````````````````P`P``$@`````````````````````````J`0``
M$@````````````````````````"G`0``$@`````````````````````````$
M`0``$@`````````````````````````I`P``$@``````````````````````
M``")`0``$@````````````````````````"'````$@``````````````````
M```````I`@``$@````````````````````````"5`@``$@``````````````
M``````````!_`P``$0````````````````````````"!`P``$0``````````
M```````````````\````(``````````````````````````)`@``$@``````
M``````````````````#H````$@````````````````````````!G`0``$@``
M``````````````````````"X`@``$@````````````````````````!0````
M(``````````````````````````0`@``$@````````````````````````!Z
M`@``$@````````````````````````"!`@``$@``````````````````````
M``#3`P``$``7`."P`0`````````````````G!```$@`-`%!3````````B```
M``````#U`P``$@`.`'14``````````````````!,!```$@`-`#A&````````
M=`D```````!Z`P``$@`-`+`A````````2`(```````#[`P``$@`-`-`^````
M````!`````````#$`P``$``7`+B@`0````````````````"Z!```$@`-`-@^
M````````%`(```````"T!```$@`+`'@=``````````````````#G!```$@`-
M`+!/````````G`,```````"X`P``$``7`+B@`0`````````````````S!```
M$@`-`/!`````````(`````````!F!```$0`/`(A4````````!`````````#F
M`P``$``7`."P`0````````````````#>`P``$``7`."P`0``````````````
M``"R!```$@`-`%@]````````.`````````#'!```$@`-`.A$````````3`$`
M``````#9!```$@`-`"A$````````F`````````!9!```$``6``"@`0``````
M``````````!`!```$@`-`!!!````````,`$```````"Q`P``$``6`+B@`0``
M``````````````";!```$0`6`+"@`0``````"`````````#K`P``$@`-`'!4
M````````!`````````"+!```$@`-`/A3````````>`````````!?!```$@`-
M`/@C``````````````````!;!```(``6``"@`0`````````````````,!```
M$@`-`,!$````````*`````````#2`P``$``7`."P`0````````````````!U
M!```$@`-`.@]````````Y`````````"E!```$@`-`$!"````````Z`$`````
M````;&EB<&5R;"YS;RXU+C(T`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V
M`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R
M<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N
M,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO
M8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK
M7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F
M7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`
M7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`7U]M96UC<'E?8VAK
M`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H
M:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E
M;G9I<F]N`&QD+6QI;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G=6%R
M9`!?961A=&$`7U]B<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?
M7P!?7V5N9%]?`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X
M96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A
M<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB
M8U]C<W5?:6YI=`!M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?
M26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,3<``````````@`"``(``@`"
M``(````"``(``@`"``(````"`````@`"```````"``(``@````(`````````
M`@`"``(```````,````#``(``@`"``,```````0``@`"``(```````(``@`"
M``(``````````@````(````"``````````(```````,``@`"``(````#````
M```"`````P`"``(``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$````!``$`B0,``!`````@````
MEY&6!@``!`#]!`````````$``0#?`0``$````"````"7D98&```#`/T$````
M`````0`!`"X"```0`````````)>1E@8```(`_00````````8FP$```````,$
M````````""4````````@FP$```````,$````````P"0```````!PGP$`````
M``,$````````<%0```````"XGP$```````,$````````"*`!``````#(GP$`
M``````,$````````^%,```````#8GP$```````,$````````L"$````````(
MH`$```````,$````````"*`!```````8H`$```````,$````````H%@`````
M```@H`$```````,$````````L%@````````HH`$```````,$````````N%@`
M```````PH`$```````,$````````P%@````````XH`$```````,$````````
MR%@```````!`H`$```````,$````````X%@```````!0H`$```````,$````
M````F%@```````!8H`$```````,$````````,%4```````!HH`$```````,$
M````````0%8```````!PH`$```````,$````````>%@```````!XH`$`````
M``,$````````@%@```````"`H`$```````,$````````B%@```````"(H`$`
M``````,$````````D%@```````"8H`$```````,$````````8%@```````"@
MH`$```````,$````````:%@```````"PH`$```````,$````````\%@`````
M``!XGP$```````$$```)``````````````"`GP$```````$$```,````````
M``````"(GP$```````$$```0``````````````"0GP$```````$$```1````
M``````````"8GP$```````$$```9``````````````"@GP$```````$$```<
M``````````````"HGP$```````$$```K``````````````"PGP$```````$$
M```L``````````````#`GP$```````$$```P``````````````#0GP$`````
M``$$```Z``````````````#@GP$```````$$``!#``````````````#HGP$`
M``````$$``!'``````````````#PGP$```````$$``!(``````````````#X
MGP$```````$$``!-``````````````!HG0$```````($```#````````````
M``!PG0$```````($```$``````````````!XG0$```````($```%````````
M``````"`G0$```````($```&``````````````"(G0$```````($```'````
M``````````"0G0$```````($```(``````````````"8G0$```````($```*
M``````````````"@G0$```````($```+``````````````"HG0$```````($
M```,``````````````"PG0$```````($```-``````````````"XG0$`````
M``($```.``````````````#`G0$```````($```/``````````````#(G0$`
M``````($```2``````````````#0G0$```````($```3``````````````#8
MG0$```````($```4``````````````#@G0$```````($```5````````````
M``#HG0$```````($```6``````````````#PG0$```````($```7````````
M``````#XG0$```````($```8````````````````G@$```````($```:````
M```````````(G@$```````($```;```````````````0G@$```````($```=
M```````````````8G@$```````($```>```````````````@G@$```````($
M```?```````````````HG@$```````($```@```````````````PG@$`````
M``($```A```````````````XG@$```````($```B``````````````!`G@$`
M``````($```C``````````````!(G@$```````($```D``````````````!0
MG@$```````($```E``````````````!8G@$```````($```F````````````
M``!@G@$```````($```G``````````````!HG@$```````($```H````````
M``````!PG@$```````($```I``````````````!XG@$```````($```J````
M``````````"`G@$```````($```K``````````````"(G@$```````($```N
M``````````````"0G@$```````($```O``````````````"8G@$```````($
M```Q``````````````"@G@$```````($```R``````````````"HG@$`````
M``($```S``````````````"PG@$```````($```T``````````````"XG@$`
M``````($```U``````````````#`G@$```````($```V``````````````#(
MG@$```````($```W``````````````#0G@$```````($```X````````````
M``#8G@$```````($```Y``````````````#@G@$```````($```[````````
M``````#HG@$```````($```\``````````````#PG@$```````($```]````
M``````````#XG@$```````($```^````````````````GP$```````($```_
M```````````````(GP$```````($``!````````````````0GP$```````($
M``!!```````````````8GP$```````($``!"```````````````@GP$`````
M``($``!$```````````````HGP$```````($``!%```````````````PGP$`
M``````($``!)```````````````XGP$```````($``!*``````````````!`
MGP$```````($``!+``````````````!(GP$```````($``!,````````````
M``!0GP$```````($``!.``````````````!8GP$```````($``!/````````
M``````!@GP$```````($``!0``````````````#]>[^I_0,`D:P!`)3]>\&H
MP`-?U@````#P>[^IT```D!&R1OD0@C61(`(?UA\@`]4?(`/5'R`#U=```)`1
MMD;Y$*(UD2`"'];0``"0$;I&^1#"-9$@`A_6T```D!&^1OD0XC61(`(?UM``
M`)`1PD;Y$`(VD2`"'];0``"0$<9&^1`B-I$@`A_6T```D!'*1OD00C:1(`(?
MUM```)`1SD;Y$&(VD2`"'];0``"0$=)&^1""-I$@`A_6T```D!'61OD0HC:1
M(`(?UM```)`1VD;Y$,(VD2`"'];0``"0$=Y&^1#B-I$@`A_6T```D!'B1OD0
M`C>1(`(?UM```)`1YD;Y$"(WD2`"'];0``"0$>I&^1!"-Y$@`A_6T```D!'N
M1OD08C>1(`(?UM```)`1\D;Y$((WD2`"'];0``"0$?9&^1"B-Y$@`A_6T```
MD!'Z1OD0PC>1(`(?UM```)`1_D;Y$.(WD2`"'];0``"0$0)'^1`".)$@`A_6
MT```D!$&1_D0(CB1(`(?UM```)`1"D?Y$$(XD2`"'];0``"0$0Y'^1!B.)$@
M`A_6T```D!$21_D0@CB1(`(?UM```)`1%D?Y$*(XD2`"'];0``"0$1I'^1#"
M.)$@`A_6T```D!$>1_D0XCB1(`(?UM```)`1(D?Y$`(YD2`"'];0``"0$29'
M^1`B.9$@`A_6T```D!$J1_D00CF1(`(?UM```)`1+D?Y$&(YD2`"'];0``"0
M$3)'^1"".9$@`A_6T```D!$V1_D0HCF1(`(?UM```)`1.D?Y$,(YD2`"'];0
M``"0$3Y'^1#B.9$@`A_6T```D!%"1_D0`CJ1(`(?UM```)`11D?Y$"(ZD2`"
M']:P``#P$4I'^1!".I$@`A_6L```\!%.1_D08CJ1(`(?UK```/`14D?Y$((Z
MD2`"']:P``#P$59'^1"B.I$@`A_6L```\!%:1_D0PCJ1(`(?UK```/`17D?Y
M$.(ZD2`"']:P``#P$6)'^1`".Y$@`A_6L```\!%F1_D0(CN1(`(?UK```/`1
M:D?Y$$([D2`"']:P``#P$6Y'^1!B.Y$@`A_6L```\!%R1_D0@CN1(`(?UK``
M`/`1=D?Y$*([D2`"']:P``#P$7I'^1#".Y$@`A_6L```\!%^1_D0XCN1(`(?
MUK```/`1@D?Y$`(\D2`"']:P``#P$89'^1`B/)$@`A_6L```\!&*1_D00CR1
M(`(?UK```/`1CD?Y$&(\D2`"']:P``#P$9)'^1""/)$@`A_6L```\!&61_D0
MHCR1(`(?UK```/`1FD?Y$,(\D2`"']:P``#P$9Y'^1#B/)$@`A_6L```\!&B
M1_D0`CV1(`(?UK```/`1ID?Y$"(]D2`"']:P``#P$:I'^1!"/9$@`A_6L```
M\!&N1_D08CV1(`(?UK```/`1LD?Y$((]D2`"'];]>[FI_0,`D?-3`:FS``#P
M]5L"J;0``/!CVD?Y]QL`^:*'!*FB(P&19`!`^:0W`/D$`(#2H%\`N:%#`9&@
M<P&1B/__EZ```/"B``#P`/!'^4+H1_GA`P*J=`P`E*```/``T$?Y``!`.6`!
M`#5-__^7P@``D$!L`/D@#@"TM```\!C__Y>`SD?Y``!`N5'__Y<?U",YE,Y'
M^8`"0+E-__^7`<A3.2$`'S(!R!,Y@`)`N4C__Y<"R%,YH5]`N0,`_))"```R
M`L@3.2$4`!$A?$"3/P`#ZV@)`%0@\'W3.?__EZ0K0/G%``"0U```D(,"`Y&F
M6$#Y`@``\$)`(9$!``#PAP!`^2%@(9&%`(!2!P@`J08$`:FB7T"Y900`N6`$
M`/E?!`!QC0<`5(0@`)%#$``1H0"`4N<`@)+ES"&+AH1`^"$$`!$_``-K!F@E
M^&'__U26`@.1!<PCB^,#`*H!``"P!`"`TD(,`!'`#D#Y(4`VD;^`'_AO__^7
M]0,`*B`#`#26`@.1MY,!D<`.0/GM_O^7````\.$#%ZH`P!:1TP0`E(`"`+24
M`@.1@`Y`^='^_Y=4__^7<]I'^>`#%2JB-T#Y80)`^4$``<KA`P"U\U-!J?5;
M0JGW&T#Y_7O'J,`#7];`#D#Y<___E_4#`"KE__\7P`I`^4`!`+3J"P"4ZO__
M%Z$``/````#P`"`AD2'@1_DL__^70P`%"\[__Q<```#PX0,7J@#@%)&P!`"4
MP`H`^:#[_[3;"P"4V___%R``@%*$_O^7[_[_EQT`@-(>`(#2Y0,`JN$#0/GB
M(P"1Y@,`D:```/``[$?YHP``\&/D1_FD``#PA+A'^;[^_Y?Q_O^7H```\`#4
M1_E```"TZ?[_%\`#7]8`````P0``D"'@`I$A'`"1P```D`#@`I$A``#+/S@`
M\:D``%2A``#P(;Q'^4$``+0@`!_6P`-?UA\@`]7!``"0P```D"'@`I$`X`*1
M(0``RR'\0Y,A_$&+(?Q!D\$``+2B``#P0OQ'^6(``+1``!_6'R`#U<`#7]8?
M(`/5_7N^J?T#`)'S"P#YTP``D&#B0CE``0`UH```\`#`1_F```"TP```D``$
M0/E1_O^7UO__ER``@%)@X@(Y\PM`^?U[PJC``U_6H```\`"@+)$!`$#Y80``
MM=K__Q<?(`/5H0``\"'X1_F!__^T_7N_J?T#`)$@`#_6_7O!J-'__Q?_@PK1
MJ```\`3@`)$)X`&1_7L`J?T#`)&B8P"1`=E'^4<@`)$C`$#YHT\!^0,`@-*!
M`$"Y@X1`^"$(P%KA@!_XGP`)ZV'\8--E_&C3)MQXTZ4<>)(A'&C3QAQPDB$`
M!JJCX$.J(0`#JN$$`?@A_O]41@`(D40`0/E"(`"10P1`^44<0/E!,$#Y8P`$
MRM\``NLA``7*(0`#RB/\7]-A!`&J(7Q`DD$\`/EA_O]4!!1`J:``9YX&)$&I
MP@!GGB$!9YZK_$+3:WD%JJ(/0/EK?4"2(3./TD%0J_)#``&+@OQ;TPH00/E"
M%`2JC?Q"TT`<82YA`6>>K7D$JJY]0)*M%T#YK0$!BP<`9IZ``&>>(!QB+N)`
M(HM"``.+IQ-`^4(`"HM,?$"2YP`!BT(`#HH#`&:>8P`)BV<`!XN#_5O38Q0,
MJN-`(XMG`2R*X@`"JF=\0))"``:+30`-BX+]0M-,>`RJXOQ;TT(4!ZJ,?4"2
MHD$BBZT;0/EC``R*KP$!B\T!)XJC`0.J;0`+B^/\0M-G>`>J2WQ`DN=\0)*M
M`0^+0P`'BF+]6]-"%`NJHD$BBZT?0/FO`0&+C0$KBJT!`ZIC_4+3K0$.BVMX
M"ZJM`0^+:WU`DD]\0))#``N*XOU;TT(4#ZJB02*+K2-`^:X!`8OM`"^*HP$#
MJFP`#(N-`0Z+[/U"TXQY#ZI.?$"2C'U`DD,`#(K"_5O30A0.JJ)!(HNM)T#Y
MKP$!BVT!+HJC`0.J9P`'B^T`#XO'_4+3YW@.JD]\0)+G?$"20P`'BN+]6]-"
M%`^JHD$BBZTK0/FN`0&+C0$OBJ,!`ZIK``N+;0$.B^O]0M-K>0^J3GQ`DFM]
M0))#``N*POU;TT(4#JJB02*+K2]`^:\!`8OM`"Z*HP$#JFP`#(N-`0^+S/U"
MTXQY#JI/?$"2C'U`DD,`#(KB_5O30A0/JJ)!(HNM,T#YK@$!BVT!+XJC`0.J
M9P`'B^T`#HOG_4+3YW@/JDY\0)+G?$"20P`'BL+]6]-"%`ZJHD$BBZTW0/FO
M`0&+C0$NBJ,!`ZIK``N+;0$/B\O]0M-K>0ZJ3WQ`DFM]0))#``N*XOU;TT(4
M#ZJB02*+K3M`^:X!`8OM`"^*HP$#JFP`#(N-`0Z+[/U"TXQY#ZI.?$"2C'U`
MDD,`#(K"_5O30A0.JJ)!(HNM/T#YKP$!BVT!+HJC`0.J9P`'B^T`#XO'_4+3
MYW@.JD]\0)+G?$"20P`'BN+]6]-"%`^JHD$BBZU#0/FN`0&+C0$OBJ,!`ZIK
M``N+;0$.B^O]0M-K>0^J3GQ`DFM]0)*O1T#Y0P`+BL+]6]-"%`ZJ[P$!BZ)!
M(HOM`"Z*HP$#JDU\0))L``R+P_U"TVYX#JJ,`0^+SGU`DJ]+0/E#``Z*HOU;
MTT(4#:KO`0&+@D$BBVP!+8J#`0.J3'Q`DF<`!XNC_4+3;7@-JN\`#XNM?4"2
MIT]`^4,`#8J"_5O30A0,JN)!(HOO``&+QP$LBN<``ZJ#_4+3;'@,JN<`"XN,
M?4"22WQ`DD,`#(IB_5O3YP`/BT(4"ZKB0"*+IU-`^>\``8NG`2N*XP`#JF,`
M#HM.?$"29P`/BV/]0M-K>`NJP_U;TV,4#JIK?4"2XT`CBZ=70/E"``N*[P`!
MBX<!+HKB``*J1P`-BV)\0)+-_4+3YP`/BZYY#JI-_%O3K14"JL]]0)+G0"V+
MK5M`^6,`#XJM`0&+80$BBB$``ZKC?$"2(0`,BW#\6],A``V+3?Q"TZUY`JH0
M%@.JP@$-RC!`,(M"``=*IU]`^0Y^0)(A=)W2(=NM\D(`"XOG``&+S/U;TT(`
M!XN,%0ZJ3$`LBV+\0M-#>`.JHF-`^:<!`\KG`!!*0@`!B^<`#XN/?4"2Z_U;
MT^<``HMK%0^JHF=`^>M`*XO'_4+3YW@.JDX``8MB``?*0@`,2D)`+8NM:T#Y
M0@`.BVY]0)+,_5O3K0$!BXP5#JI,0"R+XOU"TT)X#ZKO``+*ZP$+2F-!(XMC
M``V+C7U`DJO]6]-K%0VJ:T`KB\/]0M-C>`ZJKF]`^4\``\KL`0Q*S@$!BX=!
M)XOG``Z+;GU`DLS]6].,%0ZJ[$`LBZ?]0M/G>`VJK7-`^6\`!\KK`0M*K0$!
MBV)!(HM"``V+C7U`DJO]6]-K%0VJ2T`KB\+]0M-">`ZJKG=`^>\``LKL`0Q*
MS@$!BX-!(XMC``Z+;GU`DLS]6].,%0ZJ;$`LBZ/]0M-C>`VJK7M`^4\``\KK
M`0M*K0$!BV=!)XOG``V+C7U`DJO]6]-K%0VJZT`KB\?]0M/G>`ZJKG]`^6\`
M!\KL`0Q*S@$!BX)!(HM"``Z+;GU`DLS]6].,%0ZJ3$`LBZ+]0M-">`VJK8-`
M^>\``LKK`0M*K0$!BV-!(XMC``V+C7U`DJO]6]-K%0VJ:T`KB\/]0M-C>`ZJ
MKH=`^4\``\KL`0Q*S@$!BX=!)XOG``Z+;GU`DLS]6].,%0ZJ[$`LBZ?]0M/G
M>`VJK8M`^6\`!\KK`0M*K0$!BV)!(HM"``V+C7U`DJO]6]-K%0VJ2T`KB\+]
M0M-">`ZJKH]`^>\``LKL`0Q*S@$!BX-!(XMC``Z+;GU`DLS]6].,%0ZJ;$`L
MBZ/]0M-C>`VJK9-`^4\``\KK`0M*K0$!BV=!)XOG``V+C7U`DJO]6]-K%0VJ
MZT`KB\?]0M/G>`ZJKI=`^6\`!\KL`0Q*S@$!BX)!(HM"``Z+;GU`DLS]6].,
M%0ZJ3$`LBZ+]0M-">`VJK9M`^>\``LKK`0M*K0$!BV-!(XMC``V+C7U`DJO]
M6].P_4+3:Q4-JA!Z#:IK0"N+P_U"TV-X#JJNGT#Y3P`#RFT`$,KL`0Q*S@$!
MBX=!)XOG``Z+;GU`DLS]6].K`0M*C!4.JF)!(HOG0"R+K"]4J8P!`8MK`0&+
M0@`,B^Q\0)*-_5O3C_U"TZT5#*KO>0RJ34`MB\+]0M-">`ZJ#@("RL<!!TKC
M0".+8P`+BZM]0))G_5O3YQ0+JF-`)XNGJT#Y;'Q`DN<``8M!``_*(0`-2H[]
M6],A0#"+SA4,JB$`!XMG_4+3ZW@+JBY`+HOA`0NJK:]`^2$``XKC`0N*(0`#
M*L=]0)(B0"*+@_U"TX&;E])C>`RJ8>.Q\JP!`8OM_%O30@`,BZT5!ZJLLT#Y
M0D`MBVT!`ZJN`0Z*C0$!BVP!`XK,`0PJ3GQ`DHQ!+XN,`0V+[?Q"TZ=Y!ZK-
M_5O3K14.JHU!+8ML``>J@@$"BJRW0/F/`0&+;``'BDP`#"K"_4+3BT$KBT)X
M#JIL`0^+JWU`DF[]6]/O``**SA4+JHY!+HOL``*JC`$-BJV[0/F,`0\JK0$!
MBX-!(XML``V+PWU`DFW]0M.K>0NJ;?Q;TZT5`ZI/``N*C4$MBTP`"ZJ,`0Z*
MKK]`^8P!#RK.`0&+AT$GB^P`#HNG?4"2;OQ"T\-Y`ZKN_%O3SA4'JF\!`XJ.
M02Z+;`$#JHP!#8JMPT#YC`$/*JT!`8N"02*+3``-B\)]0)+M_$+3IWD'JDW\
M6].M%0*J;P`'BHU!+8ML``>JC`$.BJ['0/F,`0\JS@$!BXM!*XML`0Z+JWU`
MDD[\0M/">0*J;OU;T\X5"ZKO``**CD$NB^P``JJ,`0V*K<M`^8P!#RJM`0&+
M@T$CBVP`#8O#?4"2;?U"TZMY"ZIM_%O3K14#JD\`"XJ-02V+3``+JHP!#HJN
MST#YC`$/*LX!`8N'02>+[``.BZ=]0))N_$+3PWD#JN[\6]/.%0>J;P$#BHY!
M+HML`0.JC`$-BJW30/F,`0\JK0$!BX)!(HM,``V+PGU`DNW\0M.G>0>J3?Q;
MTZT5`JIO``>*C4$MBVP`!ZJ,`0Z*KM=`^8P!#RK.`0&+BT$KBVP!#HNK?4"2
M3OQ"T\)Y`JIN_5O3SA4+JN\``HJ.02Z+[``"JHP!#8JMVT#YC`$/*JT!`8N#
M02.+;``-B\-]0))M_4+3JWD+JFW\6].M%0.J3P`+BHU!+8M,``NJC`$.BJ[?
M0/F,`0\JS@$!BX=!)XOL``Z+IWU`DF[\0M/#>0.J[OQ;T\X5!ZIO`0.*CD$N
MBVP!`ZJ,`0V*K>-`^8P!#RJM`0&+@D$BBTP`#8O"?4"2[?Q"TZ=Y!ZI-_%O3
MK14"JF\`!XJ-02V+;``'JHP!#HJNYT#YC`$/*LX!`8N+02N+;`$.BZM]0)).
M_$+3PGD"JF[]6]/.%0NJ[P`"BHY!+HOL``*JC`$-BJWK0/F,`0\JK0$!BX-!
M(XML``V+PWU`DFW]0M.K>0NJ;?Q;TZT5`ZI/``N*C$$MBTT`"ZJM`0Z*KN]`
M^:T!#RJ/?4"2IT$GBVW\0M.C>0.JS@$!B^W]6]/G``Z+K14/JNU`+8MG`0.J
M[``,BJ?S0/GN``&+9P$#BH<!!RKB0"*+1P`.BZY]0)+B_4+3S/U;TT)X#ZJ,
M%0ZJ[$`LBV<``JIO``**YP`-BJWW0/GG``\JYT`KBX]]0)*M`0&+R_U"T^<`
M#8OM_5O3:WD.JJT5#ZKM0"V+1P`+JN<`#(JL^T#YKGU`D@C91_F,`0&+00`+
MBN$``2KG_4+3(4`CB\/]6]/G>`^J(0`,BV,4#JJL_T#Y(T`CBV$!!\HM``U*
MP3J8TD%,N?)P?$"2C`$!BZ)!(HM"``R+#/Y;TXP5$*I,0"R+POU"TT]X#JJB
M`T'Y30`!B^(`#\I"``-*`_Y"TT)`*XMC>!"J0@`-BXU]0)*K_5O3[@$#RFL5
M#:K,`0Q*2T`KBZ('0?EN?4"2AT$GBT(``8O,_5O3YP`"BXP5#JKL0"R+H@M!
M^:?]0M/G>`VJ30`!BV(`!\I"``M*0D`OBT(`#8N-?4"2J_U;TVL5#:I+0"N+
MPOU"TT)X#JJN#T'Y[P`"RNP!#$K.`0&+@T$CBV,`#HMN?4"2S/U;TXP5#JIL
M0"R+H_U"TV-X#:JM$T'Y3P`#RNL!"TJM`0&+9T$GB^<`#8N-?4"2J_U;TVL5
M#:KK0"N+Q_U"T^=X#JJN%T'Y;P`'RNP!#$K.`0&+@D$BBT(`#HMN?4"2S/U;
MTXP5#JI,0"R+HOU"TT)X#:JM&T'Y[P`"RNL!"TJM`0&+8T$CBV,`#8N-?4"2
MJ_U;TVL5#:IK0"N+P_U"TV-X#JJN'T'Y3P`#RNP!#$K.`0&+AT$GB^<`#HMN
M?4"2S/U;TXP5#JKL0"R+I_U"T^=X#:JM(T'Y;P`'RNL!"TJM`0&+8D$BBT(`
M#8N-?4"2J_U;TVL5#:I+0"N+POU"TT)X#JJN)T'Y[P`"RNP!#$K.`0&+@T$C
MBV,`#HMN?4"2S/U;TXP5#JIL0"R+H_U"TV-X#:JM*T'Y3P`#RNL!"TJM`0&+
M9T$GB^<`#8N-?4"2J_U;TVL5#:KK0"N+Q_U"T^=X#JJN+T'Y;P`'RNP!#$K.
M`0&+@D$BBT(`#HMN?4"2S/U;TXP5#JI,0"R+HOU"TT)X#:JM,T'Y[P`"RNL!
M"TJM`0&+8T$CBV,`#8N-?4"2J_U;TVL5#:IK0"N+P_U"TV-X#JJN-T'Y3P`#
MRNP!#$K.`0&+AT$GB^<`#HMN?4"2S/U;TXP5#JKL0"R+I_U"T^=X#:JM.T'Y
M;P`'RNL!"TJM`0&+8D$BBT(`#8N-?4"2J_U;TVL5#:I+0"N+POU"TTYX#JJB
M/T'Y[P`.RNP!#$I"``&+@T$CBV,``HMB?4"23/Q;TXP5`JIL0"R+H_U"TVUX
M#:JC0T'YSP$-RNL!"TIC``&+9T$GB^<``XN#?4"2:_Q;TVL5`ZKK0"N+1_Q"
MT^)X`JI'``H+J@$"RDH!#$IL_$+3@WD#JDI!+HM"``/*8P`)"P.<`:E"``M*
MIT=!^4)`+8NC2T'YYP`!BTH!!XMA``&+9WU`DD(``8OA_%O3X_Q"TR$4!ZIG
M>`>J(0`*"^8`!@LC_%O3I0`!"V$4`:H&"`#Y(0`""R$`!`L!%`"IH4]!^0`!
M0/D@``#*@```M?U[0*G_@PJ1P`-?UD?Z_Y?]>[RI_0,`D?-3`:GU6P*I]V,#
MJ8`&`+2B``#00O1'^5@`0/D8!@"T`@!`.14`@%)?]`!Q1!A`>@$#`%03`T#Y
M\P$`M/<#`:KV`P"JM7Y`D_0#&*K@`Q.JX@,5JN$#%JH&^O^7@```-6!J=3@?
M]`!Q0`(`5)..0/CS_O^UX`,3JO-30:GU6T*I]V-#J?U[Q*C``U_6'R`#U?4#
M`*JB'D`X7_0`<4080'JA__]4M0(`2^/__Q<?(`/5@`(8R[4&`)$`_$.3X`(`
MN7,"%8O@`Q.J\U-!J?5;0JGW8T.I_7O$J,`#7]83`(#2Y?__%Q\@`]7]>[RI
M_0,`D?5;`JFV``#0\U,!J;,``-#U`P"JP-I'^7/V1_FTTP"1`0!`^:$?`/D!
M`(#2X0,4JN`#%:JU__^7X`$`M*,W@+EB`D#Y0`P#BP$$0/E!>"/XX?[_M``@
M`)$!!$#Y`0``^:'__[7A`Q2JX`,5JJ?__Y=@_O^UUMI'^:$?0/G``D#Y(```
MRJ```+7S4T&I]5M"J?U[Q*C``U_6XOG_EQ\@`]7]>[FI_0,`D?-3`:GS`P&J
M]5L"J;4``-#W8P.I]`,`JOEK!*G[*P#YH=I'^6`"0#DB`$#YHC<`^0(`@-(?
M]`!Q<Q:3FN`#$ZI:^?^7]P,`JJ&3`9'@`Q2JA/__ER`(`+3V`P"J4_G_E_\"
M`.OI!@!4MF>`N;D``-#6\GW3@`)`.1_T`'$$&$!Z(`P`5.$#%*H@'$`X'_0`
M<0080'JA__]4(0`4RR%\0),Y]T?YX`H`D0```8LW`T#Y>OG_E^!J-O@`"P"T
MHV>`N8`&`)$B`T#Y@0)`.3_T`'%">&/X)!A`>D$``#G```!4`11`.$$<`#@_
M]`!Q)!A`>H'__U1!!`"1H`>`4D```#E@%D`X(!0`.,#__S4``(!2M=I'^:(W
M0/FA`D#Y00`!R@$(`+7S4T&I]5M"J?=C0ZGY:T2I^RM`^?U[QZC``U_6``"`
MTF%J8#C!:B`X``0`D:'__S7N__\7N0``T"#W1_D6`$#YP`)`^2`%`+3A`Q:J
M``"`4@(``!3@`Q@J(HQ`^!@$`!&B__^U``P`$0!\?9.A``#P(L!`N<(!`#3A
M`P"JX`,6JFWY_Y<A]T?Y(```^4`#`+0;?T"3^@,`JG;S?=-[!P"17WL[^+AG
M`+FJ__\7(@"`4B+``+DP^?^7^@,`JL`!`+0;?T"3X0,6JG;S?=/B`Q:JY?C_
MER#W1_D:``#Y\/__%P$`@-*F__\7``*`TA@`@%+?__\7``"`$KW__Q=6^?^7
M'R`#U?U[LJG]`P"1]5L"J;4``-#S4P&I]V,#J?EK!*FAVD?Y(@!`^:)O`/D"
M`(#2@```M`$`0#GV`P"J@0$`-;7:1_FA;T#YH`)`^2```,K`"`"U\U-!J?5;
M0JGW8T.I^6M$J?U[SJC``U_6XOC_E_<#`*I@_O^T&```T+EC`9$8(Q.1U`6`
M4N`#%ZIV^?^7H`4`M`%,0#F!`@%KX0``5`%00#DA__\T@0(!:^$#`4M!``!4
M`51`.8'^_S033`"1X`,6JK#X_Y?Z`P"JX`,3JJWX_Y<``!H+``@`$0!\0)/E
M^/^7Y0,3JN0#%JKC`QBJ^@,`J@(`@)(A`(!2IOC_E^(#&:KA`QJJ``"`4JKX
M_Y<?!``QH```5*!K0+D`#!02'Q!`<<`!`%3@`QJJ@OG_E^`#&JI$^?^7X`,7
MJDKY_Y>@^O^UX`,7JO_X_Y?@`Q:J*?G_E[O__Q<?(`/5X`,:JJG__Y?S__\7
M^_C_E_U[OJG]`P"1\U,!J;,``-#T`P"J<\Y'^6`"0+GG^/^7`N`'D>$#%*H`
M`(!2)_G_E\```#0``(!2\U-!J?U[PJC``U_6'R`#U6`"0+G;^/^7``A"N0`,
M%!(?$$!QX```5&`"0+G5^/^7``A"N0`,%!(?*$!Q`?[_5$$`@%+@`Q2J[OC_
MEQ\``''@%Y\:\U-!J?U[PJC``U_6\`F"DO]C,(OB_X'2_7L`J?T#`)'S4P&I
MM```T/5;`JFU(P&1]QL`^?8#`*J#VD?Y````T/<#`:H`0!.19`!`^:0G"/D$
M`(#2X0,5JEWX_Y<?``!Q#00`5`,$`%&ARF,X@0,`-.,#`"IS?$"3X06`4N(#
M$ZK@`Q6J%OG_E\`"`+2@``#0`,Q'^0``0+FE^/^7XP,3JN(#%:KA`Q:J%?G_
MEY3:1_FA)TCY@`)`^2```,H@`@"U\U-!J1`*@M+U6T*I_7M`J?<;0/G_8S"+
MP`-?UL/\_S6@``#0`,Q'^0``0+F0^/^7X@,7JN$#%JIM^/^7[/__%Y?X_Y?]
M>[^IH```T/T#`)$`S$?Y``!`N87X_Y>B``#0`P``T/U[P:@!``#00LA'^6-`
M$I$A@!.1O?C_%_U[OJG]`P"1\PL`^;,``-!SSD?Y8`)`N7;X_Y?K__^78`)`
MN7/X_Y?S"T#Y_7O"J`0``-"$`"&1`@``L`$``-`%`(!2XP,$JD+`/I$A`!21
MQ/C_%Q\@`]7P"822_V,PB_U[`*G]`P"1\U,!J;0``-#U6P*IL^,`D8#:1_D!
M`$#YH2<0^0$`@-(J^/^7Y`,`*@4``-`#``#0(@""TJ5@%)%C@!21(0"`4N`#
M$ZKM]_^7``3X-P`(@M*V`P"+`@""TN`#$ZKA`Q:J\O?_E_,#`*H``_@W``0`
M$0!\0),9^/^7]0,`JL```+1S?D"3X0,6JN(#$ZK+]_^7OVHS.)3:1_G@`Q6J
MHB=0^8$"0/E!``'*00$`M?-30:D0"H32]5M"J?U[0*G_8S"+P`-?UA\@`]45
M`(#2\O__%SKX_Y<?(`/5QO__%Q\@`]7P#8*2_V,PB_U[`*G]`P"1]V,#J;<`
M`-#S4P&I]`,`JO5;`JGS`P&J^6L$J:&3`9'[*P#Y````T.+:1_D`X!210P!`
M^:,W"/D#`(#2W?W_E_4#`*KA!8!2X`,4JG/X_Y>``@"T````T.$#%*H`(!61
M.O[_E^`#%*KWVD?YHC=(^>$"0/E!``'*00P`M?-30:D0#H+2]5M"J?=C0ZGY
M:T2I_7M`J?LK0/G_8S"+P`-?UN`#%*H6``#0E/?_E]9B%9'Z`P`JX0,6JN`#
M$ZJ+]_^7\P,`JH#\_[1@`D`Y&0``T!@``-`Y@Q61&*,5D:`&`#2U``"TX0,3
MJN`#%:H7^/^7(`4`-.`#$ZJ`]_^78<(@BR'P7S@_O`!QX0``5``$`%%APB"+
M?\H@."'P7S@_O`!Q8/__5$$'`!$@```+'_P_<2SY_U3D`Q.JLP``L+NC`9$"
M`(+2(0"`4N8#%*KE`QFJXP,8JN`#&ZIL]_^7<\Y'^6`"0+G-]_^7`N`'D>$#
M&ZH``(!2;??_E^```#5@`D"YQO?_EP`(0KD`#!02'R!`<2`"`%3A`Q:J``"`
MTE/W_Y?S`P"J@/7_M&`"0#F@^?\U$P``L'/"%)&U``"TX0,3JN`#%:KA]_^7
M8/[_-"``@%+5__\7(0"`4N`#&ZK/]_^7H/W_->$#&ZH```"P`"`5D=;]_Y?@
M`QNJ:/?_EYO__Q>R]_^7'R`#U0$`0#G!```T`@0`D3^\`'$`$(*:011`.*'_
M_S7``U_6_7N^J?T#`)'S4P&I8`,`M!0`0#GS`P"J%`,`-"WW_Y<`!`#18@(`
MBW\"`NMB!`!48&I@.!^\`'&@``!4'```%$``0#D?O`!Q(0,`5$($`-%_`@+K
M8?__5)^^`''@``!4\U-!J0```+#]>\*H`(`5D4#W_Q<?(`/50`"`TE'W_Y<`
M!0"T`@``L$+`%)%"`$!Y`@``>?-30:G]>\*HP`-?UD``0#D?O`!Q@`$`5$($
M`-%_`@+K8___5'\"`NO@_/]40@0`T7\"`NOB``!40`!`.1^\`'&!``!40@0`
MT7\"`NMC__]40@`3RT`(`)$?!$#QB`$`5*```-`4@`.1X0,3J@,`@M)"!`"1
MX`,4JC'W_Y?@`Q2J\U-!J?U[PJC``U_6``"`TO-30:G]>\*HP`-?UOU[N*D!
M``"P(4`2D0```+#]`P"1\U,!J2)``)&S``"P]5L"J28<0:GW8P.I)!1"J:8?
M!:EAVD?Y`,`5D4)`0'D6``"PHN,`>2(`0/FB/P#Y`@"`TJ07!JD7``"P&```
ML!0``+`Y_?^7E$(7D0```+```!:1-?W_E[4S`9$```"P`"`6D3']_Y<```"P
M`&`6D2[]_Y?`@A:1+/W_EP```+``P!:1*?W_E^#B%)$G_?^7``,7D27]_Y?@
M`Q2J(_W_EP```+``@!>1(/W_EP```+``(!61'?W_EP```+``P!>1&OW_EP``
M`+```!B1%_W_EP```+#A`Q6J`$`8D=?\_Y>```"TX0,`JN`#%*HY_?^7````
ML.$#%:H`H!B1S_S_EZ```+0"``"PX0,`JD``&9$P_?^7````L.$#%:H`0!F1
MQOS_EV`"`+3A`P"JX.(4D2C]_Y<!``"PP((6D2$@&I$D_?^7<]I'^:$_0/E@
M`D#Y(```RH`#`+7S4T&I]5M"J?=C0ZG]>\BHP`-?UA\@`]4```"PX0,5J@"`
M&9&O_/^7P```M.$#`*H``Q>1$?W_E^G__Q<?(`/5`0``L+1#`9%"`8#2(>`9
MD:"'`9'!]O^7(/S_-8%N`)$``Q>1!?W_E]W__Q?C]O^7_7N]J?T#`)'S4P&I
MLP``L+0``-!AVD?Y@!)`N2(`0/FB%P#Y`@"`TA\$`#$@`0!4<]I'^:(70/EA
M`D#Y00`!RJ$"`+7S4T&I_7O#J,`#7]8```"PH9,`D0``%Y&%_/^70`$`M`$`
M0#D_P`!QX`>?&C\``''A!Y\:```!"H`2`+GL__\7'R`#U0``@%*`$@"YZ/__
M%[WV_Y?]>[^I_0,`D5[V_Y?=]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7
M_7NUJ:$``-`A0`"1_0,`D?=C`ZFX``"P\U,!J?5;`JGV`P"J^6L$J0/;1_G[
M*P#Y,P1`^2:<0:EB`$#YHE<`^0(`@-(DE$*IIA\(J2`<0/DA"$#YI!<)J;,'
M!ZF@4P#Y,P,`M`$``+````"PM>,!D;>S`9$Z8!61&:`5D08``!3A`Q:J`??_
MEX`#`+2SAD#XLP$`M.$#%ZK@`Q.J1?S_E_0#`*I@``"T`0!`.:'^_S7@`Q.J
MX0,6JJ3\_Y>SAD#XL_[_M1C;1_FA5T#Y``-`^2```,J@`P"U\U-!J?5;0JGW
M8T.I^6M$J?LK0/G]>\NHP`-?UA\@`]7@`Q:J__7_E_L#`*K@`Q2J_/7_EV`#
M`(L`"`"1-?;_E^8#%*KE`QJJY`,6JN,#&:H"`("2^P,`JB$`@%+U]?^7X0,;
MJN`#$ZJ"_/^7TO__%V#V_Y<?(`/5\#F0DO]C,(NA``#0(4``D2)@`9$(!)#2
M_7L!J?U#`)&H`PB+))1%J?=C!*FX``"P\U,"J?5;`ZFT`P.1^6L%J;E#`I'[
M<P:ILZ,"D0/;1_GV`P"J)AQ$J6D`0/D)S0#Y"0"`TB,H0/FU,P*1A!8`J1H`
M`+!$%$&I(PL`^2-,0/D@A$BI8`8`J4`$0JF`!@*I)A\`J>$#%:J$%@&I0.,4
MD6,*`/GO^_^7@```M`$`0#GW`P"JH2$`-73__Y<7`(#2_`,`JN`.`+3@`QRJ
MM_7_EP#X?],`!`"1\/7_EX0#0#GW`P"JA`$`-!L``+#S`Q>J>V,:D>`#$ZKC
M`QNJ`@"`DB$`@%*M]?^7<PH`D80?0#@D__\UH&-`^4`"`+24(@"1!```%!\@
M`]6`AD#XH`$`M.$#%:K+^_^7\P,`JF#__[0!`$`Y(?__-!+]_Y?@_O\TX`,3
MJKWU_Y?S`P"JH`$`M10`@%(SVW3X,P$`M&`"0#G@```TX`,3J@;]_Y=@"@`U
ME`8`$3/;=/@S__^U$P"`TN`#$ZJ%]?^7^P,`JN`#%ZJ"]?^7&P`;"WL3$!%[
M?T"3X`,;JKGU_Y?G`Q>JY`,3J@$``+`&``"P)8`5D<:`&I$#``"P8Z`:D0(`
M@)+T`P"J(0"`4G7U_Y<!.(!2X`,4JE[V_Y<?!``Q0`<`5+,``+!SSD?Y8`)`
MN=#U_Y<"X`>1X0,4J@``@%(0]O^7]P,`*@`(`#2@``"PPP)`^0(``+#D`Q2J
M`,1'^4(`'9$A`(!2$P"`T@``0/GH]?^7&-M'^0$$D-*A`P&+X`,3JB+,0/D!
M`T#Y00`!RD$X`+7S4T*I$#J0TO5;0ZGW8T2I^6M%J?MS1JG]>T&I_V,PB\`#
M7]9N]?^7_`,`JH#Q_[7W(@"1X&IS^,`2`+3A`Q6J;?O_EV#__[0!`$`YP?[_
M-?<B`)'X__\7'R`#U>`#$ZJ4!@`17O7_E_,#`*I@]/^TK?__%QKV_Y<%`$"Y
MOT0`<8#X_U2@``"PPP)`^0(``+#D`Q2J`,1'^4+@&I$A`(!2$P"`T@``0/FU
M]?^7S?__%Q\@`]5@`D"YB?7_EP`(0KD`#!02'Q!`<8'W_U1@`D"Y@_7_EQP0
M0KDQ]?^7GP,`:\'V_U1@`D"Y??7_EP`(0KD`(``2'P`'<0'V_U3@`QNJ2_7_
ME^$#%:KS`P"J````L```(Y$X^_^7H`P`M-4"0/DO]?^7X0,`JN`#%:I"_?^7
M]0,`JL`+`+3@`Q6J`/7_E_L#`*H?#`!Q[0$`5`!\0),!``"P`!``T2'@&Y&@
M`@"+B_7_EP`!`#5_$P!Q`"8`5&`3`%&@PB"+`/!?.!^\`'%@)0!4@/[_E\``
M`#4!`(!2X`,5JL+U_Y>@?P"YP`@`-0$``+````"P(2`:D0``%Y%W^_^7%0``
ML````+`9@!61]@,9JK6B')$5]?^7Y@,`*@<``+#G`"&1`P``L/L#!ZIC8!R1
MY0,9JN0#%*H"`("2(0"`4N`#$ZK5]/^7$@``%!\@`]6V]?^7``!`N1]$`'%!
M`@!4`O7_E_L#`/GW!@`1Y@,`*N<#%RKE`Q:JY`,4JN,#%:H"`("2(0"`4N`#
M$ZK#]/^7`3B`4N`#$ZJL]?^7'P0`,8#]_U3@`Q2J:/7_E^$#$ZI`XQ212?O_
ME^`#$ZIU_O^76___%Q\@`]5R_O^7X`,7JM;T_Y?S`P"J5?__%Z`!@-+F]/^7
M'```L/<#`*ID"H!2G$,:D?7^_Q?5`D#YHO__%T(`@%(A`H"2`/7_E[OC!I&@
M?T"YP@"`TN$#&ZIK]?^7H.-&.8```#6@YT8Y'PP!<<`=`%2@?T"Y`0"`T@(`
M@%*WPP.1O*,$D?#T_Y>__Q&I('&5TB%@A-*@^;WRH>BL\J$##ZG`CHK20`:B
M\L&?F])!%[/RH0,0J0`^G-*_:P&Y0'JX\J"+`/G@X@"1H#L`^:!_0+D"`)#2
MX0,;JDOU_Y?C`P"J'P``<?8#`"K-"`!4HH]`^6!\0)-!#``+7P`!ZZ*30/E)
M``!40@0`D4!T0(NA@Q&IH&M!N<`4`#0!"(!2-@``2W\`%FNA.T#Y=M"6&J,W
M`/G9?D"3(,`@B^(#&:KA`QNJ5?3_EZ!K0;FC-T#YP`(`"Z!K`;D?``%QH?O_
M5'8`%DMY`QF+X`,7JB_V_Y??_@!QS0(`5-8"`5'`?@93H&L`N15D>M.U`@&1
M-0,5BR8?0*F&'P"I)!=!J807`:DB#T*I@@\"J2@G0ZF()P.IX`,7JCD#`9$<
M]O^7OP(9ZX'^_U2@:T"YUAH`2Z`[0/D#"8#2PGY`D^$#&:IO]/^7MFL!N:!_
M0+D"`)#2X0,;J@;U_Y?C`P"J'P``<?8#`"J,]_]4H']`N:CT_Y>UVU&IX0^`
M$J`B0].!RR`X``0`$1_@`'%L#@!4X>(`D0('@%)"``!+(,`@BT)\0),!`(!2
M=O3_E\'^6-/`_E#3H8,%.:'^6-.@AP4YP/Y(TZ"+!3F@_E#3H)<%.:#^2-.V
MCP4YO",&D:&3!3D;``"PM9\%.?8#'*J@FP4YX`,7JN?U_Y=U8QJ1I0]/J:7/
M!3FB!U"IH]\%.:1\&%.F_%#3I?Q(TZ7+!3EE_%C3I=,%.67\4--C_$C3H]L%
M.4/\6-.@BT#YM\<%D:+O!3F;HP"1H^,%.4/\4--"_$C3HNL%.2+\6-.A_P4Y
MHO,%.2+\4-,A_$C3H?L%.0'\6-.@#P8YH0,&.0'\4-.DPP4Y`/Q(TZ;'!3FE
MUP4YH^<%.:+W!3FA!P8YH`L&.0(``!3D%D`XX`,6JN,#%:H"`("2(0"`4M8*
M`)'B\_^7?P,6ZP'__U0'``"PY@,<JN<`(9$#``"PO\,&.>0#%*IC(!R1````
ML`6`%9$"`("2(0"`4N`#$ZK3\_^7X`,4JGWT_Y?A`Q.J0.,4D5[Z_Y?@`Q.J
MBOW_EW#^_Q?Y`QNJ;___%]8&0/FVVO^TX`,6JL'S_Y<?#`#Q*=K_5``0`-$!
M``"PP`(`BR$`')%.]/^7'P``<;42EIK)_O\7`@B`4D(``$M"?$"3`0"`4OOB
M`)%@PR"+!/3_E^`#%ZJ&]?^7__X#J?_^!*G__@6I_S8`^8C__Q>@ZT8Y'P0!
M<2'B_U2@[T8Y'PP!<<'A_U2@\T8Y'R`!<6'A_U2@]T8Y'Q0!<0'A_U2U?T"Y
M0@"`4B$'@)+@`Q4J^//_E^$#&ZHB!8#2X`,5*F3T_Y<'``"PY@,;J@,``+#G
M`"&1N?__%P+T_Y<?(`/5_7NXJ?T#`)'W8P.IN```L*#3`9'S4P&I]5L"J?4#
M`*H3ST?YH#<`^:```+#Y:P2I^W,%J0#81_D!`$#YH3\`^0$`@-)@`D"YXO/_
ME_0#`*I@`D"YW_/_EP#`0CF`Q@(YX0,5J@```)``@!:1G_G_EX```+0!`$`Y
M/\0`<>`2`%2$_/^7%L]'^;L``+#``D"YT//_EP$``)!C`8!2(@"`4B%@'I'?
M\_^78`8`M'4#`Y$!"$#YH`9`N3<40/D?!`!QK04`5!F`@%(4`(!2,P"`4AD$
MH'(*```400A`^>`#&JKH\_^7X`,`-:`&0+ES!@`1E`8`$1\`$VN-`P!4P`)`
MN;3S_Y<#`(!2@GY`D^$#%ZH4]/^7_`,`JD`"`+0"`$#YHP9`^4`,0+EZV'/X
M```9"A\`$'$@_?]4P`)`N:7S_Y>!`T#Y0P"`4@(`@-*1\_^7X0,`JN`#&JK*
M\_^78/S_-&`#`Y$`!$"Y`00`43\`%&O`"P!4%,]'^8`"0+F5\_^7`0``D&,`
M@%(B`(!2(8`>D:3S_Y?S`P"J@`$`M(`"0+F,\_^780I`^0(``)!"H!Z1(0!`
M^6?S_Y=@"D#Y``!`^0`,0+G@#+`W%,]'^8`"0+F`\_^7`0``D&,`@%(B`(!2
M(<`>D8_S_Y?S`P"JH`$`M*$W0/D```"0`"`5D3OY_Y?U`P"J@`)`N=4)`+1Q
M\_^780I`^>(#%:HA`$#Y3?/_EQC/1_ET`P.1``-`N6GS_Y?S`P"J``-`N6;S
M_Y<B`(!2`0``D"'@'I&:\_^7`@``D.$#`*I"0!^1X`,3JCWS_Y<``T"Y6_/_
MEQ_$`CFA-T#Y````D`#@%)$<^?^7@`H`^?,#`*K@!`"T`3B`4N`#$ZK8\_^7
M`00`$3\$`'$$B%%ZX08`5*```)`:V$?YH3]`^4`#0/D@``#*``8`M?-30:GU
M6T*I]V-#J?EK1*G[<T6I_7O(J,`#7]8`!$`Y0.W_-&C__Q<?(`/5'P0`<4WT
M_U05ST?Y=`,#D3,`@%*@`D"Y<P8`$3/S_Y?A`Q>JZ?+_EX`&0+D?`!-K+/__
M5);__Q>`!D#YV?S_EX`*`/GS`P"JP/K_M0```)``8!^18?/_ER3S_Y=@`P.1
M8@I`^0$$0/E``$#Y(0!`^5;Z_Y>Q__\7@`)`N1OS_Y=A"D#Y(0!`^6SS_Y>5
M__\7(O/_EWL#`Y$!``"0XP,`*B``()'B`Q.J80=`^2$`0/E*\_^7'R`#U?U[
MOJG]`P"1\U,!J?0#`*IL^_^7`0!`.<$"`#0"!`"1\P,`JC^\`'%S$H*:011`
M.*'__S4I_/^7GP(`\0080'H@`0!4@`)`.>```#0!``"0X`,3JB&`&I%R\_^7
M?P(`Z\```%3S4T&I_7O"J,`#7];S`P"J\/__%^`#%*KS4T&I_7O"J*/Y_Q>C
M``"08]Q'^8,``+1C`$#YHO+_%Q\@`]4#`(#2G_+_%_U[O*G]`P"1]5L"J;4`
M`)#S4P&IM6(LD;0``)"4@BR1E`(5R_=C`ZGV`P*J^`,`*O<#`:J4_D.34O+_
MEU0!`+03`(#2HWIS^.(#%JKA`Q>JX`,8*G,&`)%@`#_6GP(3ZR'__U3S4T&I
M]5M"J?=C0ZG]>\2HP`-?UL`#7];]>[^I_0,`D?U[P:C``U_6``````$``@``
M````<&5R;'AS:2YC`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@```````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`````&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%35``
M`````````%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S
M``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!
M3@````````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]!
M4D=#``````````!005)?05)'5E\P````````4$%27T=,3T)!3%]$14)51P``
M````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@``````
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.``````````!005)?
M0TQ%04X]````````,0````````!365-414T``"4P,G@`````<&%R+0`````E
M<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````'!A<FP`````+G!A
M<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP
M+25U+25U)7,``````````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H```````!!4D=6`````!@`````````<&5R;``````P````````
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#,V````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``````````"5S````````+64````````M+0```````%5315(`````55-%
M4DY!344``````````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````
M+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`
M````1%E,1%],24)205)97U!!5$@`````````4TA,24)?4$%42````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.
M1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,[
M"FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E
M;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D[
M"D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M
M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^
M("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S
M:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?
M=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I
M"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^
M9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM
M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F
M)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T
M;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?
M,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[
M(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I
M('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C
M86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P
M<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["FUY("1S
M:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@-3$R.PIM>2`D:61X
M(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ92!I9B`D;V9F<V5T
M(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O<B!D:64@<7%;<V5E
M:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@)&YR96%D(#T@<F5A
M9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@)&]F9G-E=#L*)&ED
M>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL87-T(&EF("1I9'@@
M/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S970@/B`Q,C@@*B`Q
M,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@)&ED>"`^/2`P.PHD
M;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O9F9S970L(#(["G)E
M860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S970@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0["B1D871A7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T.PIW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(
M3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@
M)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A
M8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D
M=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K
M*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP;2(L("1F:6QE;F%M
M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE
M(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E
M='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T
M(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F
M:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#$R."HQ
M,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F
M:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B
M.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O
M=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z
M.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P
M*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D
M=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C
M*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@
M(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D
M<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G
M.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O
M<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D[
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L
M<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D
M;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];
M7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@
M)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL[
M"FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C
M;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[
M8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N
M="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I
M*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@
M)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$
M-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H
M)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C:&5?;F%M92`]("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N
M86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI
M*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M/F-L;W-E.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN97<["B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT
M(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D
M;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX
M.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O
M;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B
M('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7
M+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N
M86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R
M.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L
M<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S
M:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R
M;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM
M>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M
M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@
M>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L
M("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE
M.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S
M92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@
M;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@
M+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*
M)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A
M8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[
M7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I
M(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O
M9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D
M)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE4
M24%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%2
M7TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,
M14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@*2!["F1E
M;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@
M0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M.PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@
M("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?
M0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V
M86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E
M='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`
M7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC
M('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M
M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI
M8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS
M:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?
M87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@
M(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*=6YL
M97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q
M*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@
M)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````()0```````,`D```````````````````!````````
M``$``````````0````````#?`0````````$`````````+@(````````!````
M`````(D#````````#`````````!X'0````````T`````````=%0````````9
M`````````!B;`0``````&P`````````(`````````!H`````````()L!````
M```<``````````@`````````]?[_;P````!@`@````````4`````````N`T`
M```````&`````````%`#````````"@`````````(!0````````L`````````
M&``````````5`````````````````````P````````!0G0$```````(`````
M``````8````````4``````````<`````````%P````````!X%P````````<`
M`````````!0````````(`````````'@#````````"0`````````8````````
M`!@```````````````````#[__]O``````$```@`````_O__;P````"@$P``
M`````/___V\``````P````````#P__]O`````,`2````````^?__;P`````7
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````D!T```````"0'0```````)`=````````
MD!T```````"0'0```````)`=````````D!T```````"0'0```````)`=````
M````D!T```````"0'0```````)`=````````D!T```````"0'0```````)`=
M````````D!T```````"0'0```````)`=````````D!T```````"0'0``````
M`)`=````````D!T```````"0'0```````)`=````````D!T```````"0'0``
M`````)`=````````D!T```````"0'0```````)`=````````D!T```````"0
M'0```````)`=````````D!T```````"0'0```````)`=````````D!T`````
M``"0'0```````)`=````````D!T```````"0'0```````)`=````````D!T`
M``````"0'0```````)`=````````D!T```````"0'0```````)`=````````
MD!T```````"0'0```````)`=````````D!T```````"0'0```````)`=````
M````D!T```````"0'0```````)`=````````D!T```````"0'0```````)`=
M````````D!T```````"0'0```````)`=````````D!T````````PFP$`````
M`'!4````````````````````````````````````````````````````````
M``````````````````````````````````````B@`0````````````````#X
M4P``````````````````L"$`````````````````````````````````````
M````````````````````````"*`!``````#_____`````*!8````````L%@`
M``````"X6````````,!8````````R%@```````#@6```````````````````
MF%@````````P50``````````````````0%8```````!X6````````(!8````
M````B%@```````"06```````````````````8%@```````!H6```````````
M````````\%@```````!'0T,Z("A58G5N='4O3&EN87)O(#8N,RXP+3)U8G5N
M='4Q*2`V+C,N,"`R,#$V,3(R.0!'0T,Z("A58G5N='4O3&EN87)O(#8N,BXQ
M+35U8G5N='4R*2`V+C(N,2`R,#$V,3(P,@``+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC
M`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````
M````````````````````````````````````````````````````````````
M``L````!`````@```````````@`````````"````````&P``````````````
M``````$````````````````````3````!P````(`````````'`(````````<
M`@```````"`````````````````````$````````````````````(0````<`
M```"`````````#P"````````/`(````````D````````````````````!```
M`````````````````#0```#V__]O`@````````!@`@```````&`"````````
M[``````````%``````````@````````````````````^````"P````(`````
M````4`,```````!0`P```````&@*````````!@````,````(`````````!@`
M````````1@````,````"`````````+@-````````N`T````````(!0``````
M`````````````0```````````````````$X```#___]O`@````````#`$@``
M`````,`2````````W@`````````%``````````(``````````@````````!;
M````_O__;P(`````````H!,```````"@$P```````&``````````!@````,`
M```(````````````````````:@````0````"```````````4`````````!0`
M``````!X`P````````4`````````"``````````8`````````'0````$````
M0@````````!X%P```````'@7``````````8````````%````%0````@`````
M````&`````````!^`````0````8`````````>!T```````!X'0```````!0`
M```````````````````$````````````````````>0````$````&````````
M`)`=````````D!T````````@!```````````````````$``````````0````
M`````(0````!````!@````````"P(0```````+`A````````Q#(`````````
M``````````@```````````````````"*`````0````8`````````=%0`````
M``!T5````````!`````````````````````$````````````````````D```
M``$````"`````````(A4````````B%0```````!H00``````````````````
M"````````````````````)@````!`````@````````#PE0```````/"5````
M````!`````````````````````0```````````````````"B````#@````,`
M````````&)L!```````8FP````````@````````````````````(````````
M``@`````````K@````\````#`````````"";`0``````()L````````(````
M````````````````"``````````(`````````+H````!`````P`````````H
MFP$``````"B;````````"`````````````````````@`````````````````
M``"_````!@````,`````````,)L!```````PFP```````"`"````````!@``
M```````(`````````!``````````R`````$````#`````````%"=`0``````
M4)T```````"P`@``````````````````"``````````(`````````,T````!
M`````P``````````H`$```````"@````````N`````````````````````@`
M``````````````````#3````"`````,`````````N*`!``````"XH```````
M`"@0```````````````````(````````````````````V`````$````P````
M````````````````N*````````!F`````````````````````0`````````!
M``````````$````#`````````````````````````!ZA````````X0``````
:``````````````$`````````````````````
